| drift_set | R Documentation |
make_drift_set builds a regular grid of drift values from a
range and step in HR units, optionally including the null drift
(HR = 1). make_drift_set_from_values converts a
user-supplied set of drift HR values to log-HR.
make_drift_set(drift_hr_range = c(0.8, 1.2), by_hr = 0.05, include_zero = TRUE)
make_drift_set_from_values(drift_hr_values, include_zero = TRUE)
drift_hr_range |
Numeric vector of length 2 giving the
inclusive range of drift HR values (e.g. |
by_hr |
Step size in HR units. |
include_zero |
If |
drift_hr_values |
Numeric vector of drift HR values. |
A numeric vector of drift values on the log-HR scale.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.