| lambdas_default | R Documentation |
A reference tuning list for the borrowing methods, used when no
calibrated tuning is supplied. The default penalty strengths
(\lambda = 0.20) are reasonable starting values for the
default scenario but should generally be replaced by calibrated
values for confirmatory use.
lambdas_default
A list with elements lambda_li, gamma_li,
lambda_p1, lambda_p2, gate_c, gate_tau,
lambda_p3, gamma_mcp, rho_mcp, lambda_p4, and
delta_bounds.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.